==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/core/itextactor.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "itextactor.h"

#include "ierror.h"

#include <vtkProp.h>


using namespace iParameter;


iTextActor::iTextActor(const iRenderTool *rv)
{
	mFontType = _TextTypeBitmap;

	mText[0] = iTextBitmap::New(rv); IERROR_ASSERT_NULL_POINTER(mText[0]);
	mText[1] = iTextVector::New(rv); IERROR_ASSERT_NULL_POINTER(mText[1]);

	this->PickableOff();
}


iTextActor::~iTextActor()
{
	for(int i=0; i<iParameter::__NumTextTypes; i++) mText[i]->Delete();
}


void iTextActor::ReleaseGraphicsResources(vtkWindow *w)
{ 
	for(int i=0; i<__NumTextTypes; i++) mText[i]->ReleaseGraphicsResources(w); 
	this->vtkProp::ReleaseGraphicsResources(w);
}


int iTextActor::RenderOverlay(vtkViewport *v)
{
	return mText[mFontType]->RenderOverlay(v);
}


int iTextActor::RenderOpaqueGeometry(vtkViewport *v)
{
	return mText[mFontType]->RenderOpaqueGeometry(v);
}

==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/core/itextactor.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "itextactor.h"

#include "ierror.h"

#include <vtkProp.h>


using namespace iParameter;


iTextActor::iTextActor(const iRenderTool *rv)
{
	mFontType = _TextTypeBitmap;

	mText[0] = iTextBitmap::New(rv); IERROR_ASSERT(mText[0]);
	mText[1] = iTextVector::New(rv); IERROR_ASSERT(mText[1]);

	this->PickableOff();
}


iTextActor::~iTextActor()
{
	for(int i=0; i<iParameter::__NumTextTypes; i++) mText[i]->Delete();
}


void iTextActor::ReleaseGraphicsResources(vtkWindow *w)
{ 
	for(int i=0; i<__NumTextTypes; i++) mText[i]->ReleaseGraphicsResources(w); 
	this->vtkProp::ReleaseGraphicsResources(w);
}


int iTextActor::RenderOverlay(vtkViewport *v)
{
	return mText[mFontType]->RenderOverlay(v);
}


int iTextActor::RenderOpaqueGeometry(vtkViewport *v)
{
	return mText[mFontType]->RenderOpaqueGeometry(v);
}
